Change bold code snippets to inline code blocks

This commit is contained in:
James Gregory 2013-12-31 17:12:29 +11:00
commit 3c76d884ef
185 changed files with 1772 additions and 1772 deletions

View file

@ -101,19 +101,19 @@ tests, as run on two 486/33 SuperVGA systems under the Phar Lap
not-very-scientific spot test, and I don't want to unfairly malign, say,
a VGA whose only sin is being plugged into a lousy motherboard, or vice
versa.) Under Phar Lap, 32-bit protected-mode apps run with full I/O
privileges, meaning that the **OUT** instructions I measured had the
best official cycle times possible on the 486: 10 cycles. **OUT**
privileges, meaning that the `OUT` instructions I measured had the
best official cycle times possible on the 486: 10 cycles. `OUT`
officially takes 16 cycles in real mode on a 486, and officially takes a
mind-boggling 30 cycles in protected mode if running *without* full I/O
privileges (as is normally the case for protected-mode applications).
Basically, I/O is just plain slow on a 486.
As slow as 30 or even 10 cycles is for an **OUT**, one could only wish
that VGA I/O were actually that fast. The fastest measured **OUT** to a
As slow as 30 or even 10 cycles is for an `OUT`, one could only wish
that VGA I/O were actually that fast. The fastest measured `OUT` to a
VGA in Table 45.1 is 26 cycles, and the slowest is 126—this for an
operation that's *supposed* to take 10 cycles. To put this in context,
**MUL** takes only 13 to 42 cycles, and a normal **MOV** to or from
system memory takes exactly one cycle on the 486. In short, **OUT**s to
`MUL` takes only 13 to 42 cycles, and a normal `MOV` to or from
system memory takes exactly one cycle on the 486. In short, `OUT`s to
VGAs are as much as 100 times slower than normal memory accesses, and
are generally two to four times slower than even display memory
accesses, although there are exceptions.